@@ -14,7 +14,13 @@
 # limitations under the License.
 #
 import os
-import mock
+
+# try/except added for compatibility with python < 3.8
+try:
+    from unittest import mock
+    from unittest.mock import AsyncMock
+except ImportError:
+    import mock
 
 import grpc
 from grpc.experimental import aio
@@ -220,6 +226,7 @@ def test_revisions_client_client_options(client_class, transport_class, transpor
             quota_project_id=None,
             client_info=transports.base.DEFAULT_CLIENT_INFO,
             always_use_jwt_access=True,
+            api_audience=None,
         )
 
     # Check the case api_endpoint is not provided and GOOGLE_API_USE_MTLS_ENDPOINT is
@@ -237,6 +244,7 @@ def test_revisions_client_client_options(client_class, transport_class, transpor
                 quota_project_id=None,
                 client_info=transports.base.DEFAULT_CLIENT_INFO,
                 always_use_jwt_access=True,
+                api_audience=None,
             )
 
     # Check the case api_endpoint is not provided and GOOGLE_API_USE_MTLS_ENDPOINT is
@@ -254,6 +262,7 @@ def test_revisions_client_client_options(client_class, transport_class, transpor
                 quota_project_id=None,
                 client_info=transports.base.DEFAULT_CLIENT_INFO,
                 always_use_jwt_access=True,
+                api_audience=None,
             )
 
     # Check the case api_endpoint is not provided and GOOGLE_API_USE_MTLS_ENDPOINT has
@@ -283,6 +292,25 @@ def test_revisions_client_client_options(client_class, transport_class, transpor
             quota_project_id="octopus",
             client_info=transports.base.DEFAULT_CLIENT_INFO,
             always_use_jwt_access=True,
+            api_audience=None,
+        )
+    # Check the case api_endpoint is provided
+    options = client_options.ClientOptions(
+        api_audience="https://language.googleapis.com"
+    )
+    with mock.patch.object(transport_class, "__init__") as patched:
+        patched.return_value = None
+        client = client_class(client_options=options, transport=transport_name)
+        patched.assert_called_once_with(
+            credentials=None,
+            credentials_file=None,
+            host=client.DEFAULT_ENDPOINT,
+            scopes=None,
+            client_cert_source_for_mtls=None,
+            quota_project_id=None,
+            client_info=transports.base.DEFAULT_CLIENT_INFO,
+            always_use_jwt_access=True,
+            api_audience="https://language.googleapis.com",
         )
 
 
@@ -348,6 +376,7 @@ def test_revisions_client_mtls_env_auto(
                 quota_project_id=None,
                 client_info=transports.base.DEFAULT_CLIENT_INFO,
                 always_use_jwt_access=True,
+                api_audience=None,
             )
 
     # Check the case ADC client cert is provided. Whether client cert is used depends on
@@ -382,6 +411,7 @@ def test_revisions_client_mtls_env_auto(
                         quota_project_id=None,
                         client_info=transports.base.DEFAULT_CLIENT_INFO,
                         always_use_jwt_access=True,
+                        api_audience=None,
                     )
 
     # Check the case client_cert_source and ADC client cert are not provided.
@@ -404,6 +434,7 @@ def test_revisions_client_mtls_env_auto(
                     quota_project_id=None,
                     client_info=transports.base.DEFAULT_CLIENT_INFO,
                     always_use_jwt_access=True,
+                    api_audience=None,
                 )
 
 
@@ -514,6 +545,7 @@ def test_revisions_client_client_options_scopes(
             quota_project_id=None,
             client_info=transports.base.DEFAULT_CLIENT_INFO,
             always_use_jwt_access=True,
+            api_audience=None,
         )
 
 
@@ -547,6 +579,7 @@ def test_revisions_client_client_options_credentials_file(
             quota_project_id=None,
             client_info=transports.base.DEFAULT_CLIENT_INFO,
             always_use_jwt_access=True,
+            api_audience=None,
         )
 
 
@@ -565,6 +598,7 @@ def test_revisions_client_client_options_from_dict():
             quota_project_id=None,
             client_info=transports.base.DEFAULT_CLIENT_INFO,
             always_use_jwt_access=True,
+            api_audience=None,
         )
 
 
@@ -598,6 +632,7 @@ def test_revisions_client_create_channel_credentials_file(
             quota_project_id=None,
             client_info=transports.base.DEFAULT_CLIENT_INFO,
             always_use_jwt_access=True,
+            api_audience=None,
         )
 
     # test that the credentials from file are saved and used as the credentials.
@@ -655,10 +690,9 @@ def test_get_revision(request_type, transport: str = "grpc"):
             generation=1068,
             launch_stage=launch_stage_pb2.LaunchStage.UNIMPLEMENTED,
             service="service_value",
-            container_concurrency=2253,
+            max_instance_request_concurrency=3436,
             service_account="service_account_value",
-            confidential=True,
-            execution_environment=vendor_settings.ExecutionEnvironment.EXECUTION_ENVIRONMENT_DEFAULT,
+            execution_environment=vendor_settings.ExecutionEnvironment.EXECUTION_ENVIRONMENT_GEN1,
             encryption_key="encryption_key_value",
             reconciling=True,
             observed_generation=2021,
@@ -679,12 +713,11 @@ def test_get_revision(request_type, transport: str = "grpc"):
     assert response.generation == 1068
     assert response.launch_stage == launch_stage_pb2.LaunchStage.UNIMPLEMENTED
     assert response.service == "service_value"
-    assert response.container_concurrency == 2253
+    assert response.max_instance_request_concurrency == 3436
     assert response.service_account == "service_account_value"
-    assert response.confidential is True
     assert (
         response.execution_environment
-        == vendor_settings.ExecutionEnvironment.EXECUTION_ENVIRONMENT_DEFAULT
+        == vendor_settings.ExecutionEnvironment.EXECUTION_ENVIRONMENT_GEN1
     )
     assert response.encryption_key == "encryption_key_value"
     assert response.reconciling is True
@@ -732,10 +765,9 @@ async def test_get_revision_async(
                 generation=1068,
                 launch_stage=launch_stage_pb2.LaunchStage.UNIMPLEMENTED,
                 service="service_value",
-                container_concurrency=2253,
+                max_instance_request_concurrency=3436,
                 service_account="service_account_value",
-                confidential=True,
-                execution_environment=vendor_settings.ExecutionEnvironment.EXECUTION_ENVIRONMENT_DEFAULT,
+                execution_environment=vendor_settings.ExecutionEnvironment.EXECUTION_ENVIRONMENT_GEN1,
                 encryption_key="encryption_key_value",
                 reconciling=True,
                 observed_generation=2021,
@@ -757,12 +789,11 @@ async def test_get_revision_async(
     assert response.generation == 1068
     assert response.launch_stage == launch_stage_pb2.LaunchStage.UNIMPLEMENTED
     assert response.service == "service_value"
-    assert response.container_concurrency == 2253
+    assert response.max_instance_request_concurrency == 3436
     assert response.service_account == "service_account_value"
-    assert response.confidential is True
     assert (
         response.execution_environment
-        == vendor_settings.ExecutionEnvironment.EXECUTION_ENVIRONMENT_DEFAULT
+        == vendor_settings.ExecutionEnvironment.EXECUTION_ENVIRONMENT_GEN1
     )
     assert response.encryption_key == "encryption_key_value"
     assert response.reconciling is True
@@ -776,16 +807,16 @@ async def test_get_revision_async_from_dict():
     await test_get_revision_async(request_type=dict)
 
 
-def test_get_revision_field_headers():
+def test_get_revision_routing_parameters():
     client = RevisionsClient(
         credentials=ga_credentials.AnonymousCredentials(),
     )
 
     # Any value that is part of the HTTP/1.1 URI should be sent as
     # a field header. Set these to a non-empty value.
-    request = revision.GetRevisionRequest()
-
-    request.name = "name_value"
+    request = revision.GetRevisionRequest(
+        {"name": "projects/sample1/locations/sample2/sample3"}
+    )
 
     # Mock the actual call within the gRPC stub, and fake the request.
     with mock.patch.object(type(client.transport.get_revision), "__call__") as call:
@@ -797,42 +828,9 @@ def test_get_revision_field_headers():
         _, args, _ = call.mock_calls[0]
         assert args[0] == request
 
-    # Establish that the field header was sent.
     _, _, kw = call.mock_calls[0]
-    assert (
-        "x-goog-request-params",
-        "name=name_value",
-    ) in kw["metadata"]
-
-
-@pytest.mark.asyncio
-async def test_get_revision_field_headers_async():
-    client = RevisionsAsyncClient(
-        credentials=ga_credentials.AnonymousCredentials(),
-    )
-
-    # Any value that is part of the HTTP/1.1 URI should be sent as
-    # a field header. Set these to a non-empty value.
-    request = revision.GetRevisionRequest()
-
-    request.name = "name_value"
-
-    # Mock the actual call within the gRPC stub, and fake the request.
-    with mock.patch.object(type(client.transport.get_revision), "__call__") as call:
-        call.return_value = grpc_helpers_async.FakeUnaryUnaryCall(revision.Revision())
-        await client.get_revision(request)
-
-        # Establish that the underlying gRPC stub method was called.
-        assert len(call.mock_calls)
-        _, args, _ = call.mock_calls[0]
-        assert args[0] == request
-
-    # Establish that the field header was sent.
-    _, _, kw = call.mock_calls[0]
-    assert (
-        "x-goog-request-params",
-        "name=name_value",
-    ) in kw["metadata"]
+    # This test doesn't assert anything useful.
+    assert kw["metadata"]
 
 
 def test_get_revision_flattened():
@@ -1004,16 +1002,16 @@ async def test_list_revisions_async_from_dict():
     await test_list_revisions_async(request_type=dict)
 
 
-def test_list_revisions_field_headers():
+def test_list_revisions_routing_parameters():
     client = RevisionsClient(
         credentials=ga_credentials.AnonymousCredentials(),
     )
 
     # Any value that is part of the HTTP/1.1 URI should be sent as
     # a field header. Set these to a non-empty value.
-    request = revision.ListRevisionsRequest()
-
-    request.parent = "parent_value"
+    request = revision.ListRevisionsRequest(
+        {"parent": "projects/sample1/locations/sample2/sample3"}
+    )
 
     # Mock the actual call within the gRPC stub, and fake the request.
     with mock.patch.object(type(client.transport.list_revisions), "__call__") as call:
@@ -1025,44 +1023,9 @@ def test_list_revisions_field_headers():
         _, args, _ = call.mock_calls[0]
         assert args[0] == request
 
-    # Establish that the field header was sent.
     _, _, kw = call.mock_calls[0]
-    assert (
-        "x-goog-request-params",
-        "parent=parent_value",
-    ) in kw["metadata"]
-
-
-@pytest.mark.asyncio
-async def test_list_revisions_field_headers_async():
-    client = RevisionsAsyncClient(
-        credentials=ga_credentials.AnonymousCredentials(),
-    )
-
-    # Any value that is part of the HTTP/1.1 URI should be sent as
-    # a field header. Set these to a non-empty value.
-    request = revision.ListRevisionsRequest()
-
-    request.parent = "parent_value"
-
-    # Mock the actual call within the gRPC stub, and fake the request.
-    with mock.patch.object(type(client.transport.list_revisions), "__call__") as call:
-        call.return_value = grpc_helpers_async.FakeUnaryUnaryCall(
-            revision.ListRevisionsResponse()
-        )
-        await client.list_revisions(request)
-
-        # Establish that the underlying gRPC stub method was called.
-        assert len(call.mock_calls)
-        _, args, _ = call.mock_calls[0]
-        assert args[0] == request
-
-    # Establish that the field header was sent.
-    _, _, kw = call.mock_calls[0]
-    assert (
-        "x-goog-request-params",
-        "parent=parent_value",
-    ) in kw["metadata"]
+    # This test doesn't assert anything useful.
+    assert kw["metadata"]
 
 
 def test_list_revisions_flattened():
@@ -1185,9 +1148,6 @@ def test_list_revisions_pager(transport_name: str = "grpc"):
         )
 
         metadata = ()
-        metadata = tuple(metadata) + (
-            gapic_v1.routing_header.to_grpc_metadata((("parent", ""),)),
-        )
         pager = client.list_revisions(request={})
 
         assert pager._metadata == metadata
@@ -1418,16 +1378,16 @@ async def test_delete_revision_async_from_dict():
     await test_delete_revision_async(request_type=dict)
 
 
-def test_delete_revision_field_headers():
+def test_delete_revision_routing_parameters():
     client = RevisionsClient(
         credentials=ga_credentials.AnonymousCredentials(),
     )
 
     # Any value that is part of the HTTP/1.1 URI should be sent as
     # a field header. Set these to a non-empty value.
-    request = revision.DeleteRevisionRequest()
-
-    request.name = "name_value"
+    request = revision.DeleteRevisionRequest(
+        {"name": "projects/sample1/locations/sample2/sample3"}
+    )
 
     # Mock the actual call within the gRPC stub, and fake the request.
     with mock.patch.object(type(client.transport.delete_revision), "__call__") as call:
@@ -1439,44 +1399,9 @@ def test_delete_revision_field_headers():
         _, args, _ = call.mock_calls[0]
         assert args[0] == request
 
-    # Establish that the field header was sent.
     _, _, kw = call.mock_calls[0]
-    assert (
-        "x-goog-request-params",
-        "name=name_value",
-    ) in kw["metadata"]
-
-
-@pytest.mark.asyncio
-async def test_delete_revision_field_headers_async():
-    client = RevisionsAsyncClient(
-        credentials=ga_credentials.AnonymousCredentials(),
-    )
-
-    # Any value that is part of the HTTP/1.1 URI should be sent as
-    # a field header. Set these to a non-empty value.
-    request = revision.DeleteRevisionRequest()
-
-    request.name = "name_value"
-
-    # Mock the actual call within the gRPC stub, and fake the request.
-    with mock.patch.object(type(client.transport.delete_revision), "__call__") as call:
-        call.return_value = grpc_helpers_async.FakeUnaryUnaryCall(
-            operations_pb2.Operation(name="operations/op")
-        )
-        await client.delete_revision(request)
-
-        # Establish that the underlying gRPC stub method was called.
-        assert len(call.mock_calls)
-        _, args, _ = call.mock_calls[0]
-        assert args[0] == request
-
-    # Establish that the field header was sent.
-    _, _, kw = call.mock_calls[0]
-    assert (
-        "x-goog-request-params",
-        "name=name_value",
-    ) in kw["metadata"]
+    # This test doesn't assert anything useful.
+    assert kw["metadata"]
 
 
 def test_delete_revision_flattened():
@@ -1787,6 +1712,28 @@ def test_revisions_transport_auth_adc(transport_class):
         )
 
 
+@pytest.mark.parametrize(
+    "transport_class",
+    [
+        transports.RevisionsGrpcTransport,
+        transports.RevisionsGrpcAsyncIOTransport,
+    ],
+)
+def test_revisions_transport_auth_gdch_credentials(transport_class):
+    host = "https://language.com"
+    api_audience_tests = [None, "https://language2.com"]
+    api_audience_expect = [host, "https://language2.com"]
+    for t, e in zip(api_audience_tests, api_audience_expect):
+        with mock.patch.object(google.auth, "default", autospec=True) as adc:
+            gdch_mock = mock.MagicMock()
+            type(gdch_mock).with_gdch_audience = mock.PropertyMock(
+                return_value=gdch_mock
+            )
+            adc.return_value = (gdch_mock, None)
+            transport_class(host=host, api_audience=t)
+            gdch_mock.with_gdch_audience.assert_called_once_with(e)
+
+
 @pytest.mark.parametrize(
     "transport_class,grpc_helpers",
     [
@@ -2409,4 +2356,5 @@ def test_api_key_credentials(client_class, transport_class):
                 quota_project_id=None,
                 client_info=transports.base.DEFAULT_CLIENT_INFO,
                 always_use_jwt_access=True,
+                api_audience=None,
             )
